@@ -2,7 +2,6 @@
 
 import base64
 import enum
-import io
 import struct
 
 import dns.enum
@@ -13,6 +12,7 @@ import dns.ipv6
 import dns.name
 import dns.rdata
 import dns.rdtypes.util
+import dns.renderer
 import dns.tokenizer
 import dns.wire
 
@@ -34,6 +34,8 @@ class ParamKey(dns.enum.IntEnum):
     IPV4HINT = 4
     ECH = 5
     IPV6HINT = 6
+    DOHPATH = 7
+    OHTTP = 8
 
     @classmethod
     def _maximum(cls):
@@ -395,6 +397,36 @@ class ECHParam(Param):
         file.write(self.ech)
 
 
+@dns.immutable.immutable
+class OHTTPParam(Param):
+    # We don't ever expect to instantiate this class, but we need
+    # a from_value() and a from_wire_parser(), so we just return None
+    # from the class methods when things are OK.
+
+    @classmethod
+    def emptiness(cls):
+        return Emptiness.ALWAYS
+
+    @classmethod
+    def from_value(cls, value):
+        if value is None or value == "":
+            return None
+        else:
+            raise ValueError("ohttp with non-empty value")
+
+    def to_text(self):
+        raise NotImplementedError  # pragma: no cover
+
+    @classmethod
+    def from_wire_parser(cls, parser, origin=None):  # pylint: disable=W0613
+        if parser.remaining() != 0:
+            raise dns.exception.FormError
+        return None
+
+    def to_wire(self, file, origin=None):  # pylint: disable=W0613
+        raise NotImplementedError  # pragma: no cover
+
+
 _class_for_key = {
     ParamKey.MANDATORY: MandatoryParam,
     ParamKey.ALPN: ALPNParam,
@@ -403,6 +435,7 @@ _class_for_key = {
     ParamKey.IPV4HINT: IPv4HintParam,
     ParamKey.ECH: ECHParam,
     ParamKey.IPV6HINT: IPv6HintParam,
+    ParamKey.OHTTP: OHTTPParam,
 }
 
 
@@ -426,7 +459,6 @@ def _validate_and_define(params, key, value):
 
 @dns.immutable.immutable
 class SVCBBase(dns.rdata.Rdata):
-
     """Base class for SVCB-like records"""
 
     # see: draft-ietf-dnsop-svcb-https-11
@@ -520,19 +552,10 @@ class SVCBBase(dns.rdata.Rdata):
         for key in sorted(self.params):
             file.write(struct.pack("!H", key))
             value = self.params[key]
-            # placeholder for length (or actual length of empty values)
-            file.write(struct.pack("!H", 0))
-            if value is None:
-                continue
-            else:
-                start = file.tell()
-                value.to_wire(file, origin)
-                end = file.tell()
-                assert end - start < 65536
-                file.seek(start - 2)
-                stuff = struct.pack("!H", end - start)
-                file.write(stuff)
-                file.seek(0, io.SEEK_END)
+            with dns.renderer.prefixed_length(file, 2):
+                # Note that we're still writing a length of zero if the value is None
+                if value is not None:
+                    value.to_wire(file, origin)
 
     @classmethod
     def from_wire_parser(cls, rdclass, rdtype, parser, origin=None):
