@@ -17,16 +17,15 @@
 
 """DNS RRsets (an RRset is a named rdataset)"""
 
-from typing import Any, cast, Collection, Dict, Optional, Union
+from typing import Any, Collection, Dict, Optional, Union, cast
 
 import dns.name
-import dns.rdataset
 import dns.rdataclass
+import dns.rdataset
 import dns.renderer
 
 
 class RRset(dns.rdataset.Rdataset):
-
     """A DNS RRset (named rdataset).
 
     RRset inherits from Rdataset, and RRsets can be treated as
@@ -132,7 +131,7 @@ class RRset(dns.rdataset.Rdataset):
         self,
         origin: Optional[dns.name.Name] = None,
         relativize: bool = True,
-        **kw: Dict[str, Any]
+        **kw: Dict[str, Any],
     ) -> str:
         """Convert the RRset into DNS zone file format.
 
@@ -159,7 +158,7 @@ class RRset(dns.rdataset.Rdataset):
         file: Any,
         compress: Optional[dns.name.CompressType] = None,  # type: ignore
         origin: Optional[dns.name.Name] = None,
-        **kw: Dict[str, Any]
+        **kw: Dict[str, Any],
     ) -> int:
         """Convert the RRset to wire format.
 
@@ -214,9 +213,9 @@ def from_text_list(
 
     if isinstance(name, str):
         name = dns.name.from_text(name, None, idna_codec=idna_codec)
-    the_rdclass = dns.rdataclass.RdataClass.make(rdclass)
-    the_rdtype = dns.rdatatype.RdataType.make(rdtype)
-    r = RRset(name, the_rdclass, the_rdtype)
+    rdclass = dns.rdataclass.RdataClass.make(rdclass)
+    rdtype = dns.rdatatype.RdataType.make(rdtype)
+    r = RRset(name, rdclass, rdtype)
     r.update_ttl(ttl)
     for t in text_rdatas:
         rd = dns.rdata.from_text(
@@ -231,7 +230,7 @@ def from_text(
     ttl: int,
     rdclass: Union[dns.rdataclass.RdataClass, str],
     rdtype: Union[dns.rdatatype.RdataType, str],
-    *text_rdatas: Any
+    *text_rdatas: Any,
 ) -> RRset:
     """Create an RRset with the specified name, TTL, class, and type and with
     the specified rdatas in text format.
