@@ -27,6 +27,7 @@ import dns.asyncresolver
 import dns.message
 import dns.name
 import dns.query
+import dns.quic
 import dns.rcode
 import dns.rdataclass
 import dns.rdatatype
@@ -78,6 +79,11 @@ KNOWN_ANYCAST_DOH_RESOLVER_URLS = [
     # 'https://dns11.quad9.net/dns-query',
 ]
 
+KNOWN_ANYCAST_DOH3_RESOLVER_URLS = [
+    "https://cloudflare-dns.com/dns-query",
+    "https://dns.google/dns-query",
+]
+
 
 class AsyncDetectionTests(unittest.TestCase):
     sniff_result = "asyncio"
@@ -474,7 +480,7 @@ class AsyncTests(unittest.TestCase):
 
             async def run():
                 q = dns.message.make_query(qname, dns.rdatatype.DNSKEY)
-                return await dns.asyncquery.udp_with_fallback(q, address, timeout=2)
+                return await dns.asyncquery.udp_with_fallback(q, address, timeout=4)
 
             (_, tcp) = self.async_run(run)
             self.assertTrue(tcp)
@@ -553,6 +559,56 @@ class AsyncTests(unittest.TestCase):
 
         self.async_run(run)
 
+    @unittest.skipIf(not dns.quic.have_quic, "aioquic not available")
+    def testDoH3GetRequest(self):
+        async def run():
+            nameserver_url = random.choice(KNOWN_ANYCAST_DOH3_RESOLVER_URLS)
+            q = dns.message.make_query("dns.google.", dns.rdatatype.A)
+            r = await dns.asyncquery.https(
+                q,
+                nameserver_url,
+                post=False,
+                timeout=4,
+                family=family,
+                http_version=dns.asyncquery.HTTPVersion.H3,
+            )
+            self.assertTrue(q.is_response(r))
+
+        self.async_run(run)
+
+    @unittest.skipIf(not dns.quic.have_quic, "aioquic not available")
+    def TestDoH3PostRequest(self):
+        async def run():
+            nameserver_url = random.choice(KNOWN_ANYCAST_DOH3_RESOLVER_URLS)
+            q = dns.message.make_query("dns.google.", dns.rdatatype.A)
+            r = await dns.asyncquery.https(
+                q,
+                nameserver_url,
+                post=True,
+                timeout=4,
+                family=family,
+                http_version=dns.asyncquery.HTTPVersion.H3,
+            )
+            self.assertTrue(q.is_response(r))
+
+        self.async_run(run)
+
+    @unittest.skipIf(not dns.quic.have_quic, "aioquic not available")
+    def TestDoH3QueryIP(self):
+        async def run():
+            nameserver_ip = "8.8.8.8"
+            q = dns.message.make_query("example.com.", dns.rdatatype.A)
+            r = dns.asyncquery.https(
+                q,
+                nameserver_ip,
+                post=False,
+                timeout=4,
+                http_version=dns.asyncquery.HTTPVersion.H3,
+            )
+            self.assertTrue(q.is_response(r))
+
+        self.async_run(run)
+
     @unittest.skipIf(not dns.query._have_httpx, "httpx not available")
     def testResolverDOH(self):
         async def run():
