@@ -28,6 +28,7 @@ except Exception:
 import dns.edns
 import dns.message
 import dns.query
+import dns.quic
 import dns.rdatatype
 import dns.resolver
 
@@ -65,6 +66,11 @@ KNOWN_ANYCAST_DOH_RESOLVER_URLS = [
     # 'https://dns11.quad9.net/dns-query',
 ]
 
+KNOWN_ANYCAST_DOH3_RESOLVER_URLS = [
+    "https://cloudflare-dns.com/dns-query",
+    "https://dns.google/dns-query",
+]
+
 KNOWN_PAD_AWARE_DOH_RESOLVER_URLS = [
     "https://cloudflare-dns.com/dns-query",
     "https://dns.google/dns-query",
@@ -183,5 +189,65 @@ class DNSOverHTTPSTestCaseHttpx(unittest.TestCase):
         self.assertTrue(has_pad)
 
 
+@unittest.skipUnless(
+    dns.quic.have_quic and tests.util.is_internet_reachable() and _have_ssl,
+    "Aioquic cannot be imported; no DNS over HTTP3 (DOH3)",
+)
+class DNSOverHTTP3TestCase(unittest.TestCase):
+    def testDoH3GetRequest(self):
+        nameserver_url = random.choice(KNOWN_ANYCAST_DOH3_RESOLVER_URLS)
+        q = dns.message.make_query("dns.google.", dns.rdatatype.A)
+        r = dns.query.https(
+            q,
+            nameserver_url,
+            post=False,
+            timeout=4,
+            family=family,
+            http_version=dns.query.HTTPVersion.H3,
+        )
+        self.assertTrue(q.is_response(r))
+
+    def testDoH3PostRequest(self):
+        nameserver_url = random.choice(KNOWN_ANYCAST_DOH3_RESOLVER_URLS)
+        q = dns.message.make_query("dns.google.", dns.rdatatype.A)
+        r = dns.query.https(
+            q,
+            nameserver_url,
+            post=True,
+            timeout=4,
+            family=family,
+            http_version=dns.query.HTTPVersion.H3,
+        )
+        self.assertTrue(q.is_response(r))
+
+    def test_build_url_from_ip(self):
+        self.assertTrue(resolver_v4_addresses or resolver_v6_addresses)
+        if resolver_v4_addresses:
+            nameserver_ip = random.choice(resolver_v4_addresses)
+            q = dns.message.make_query("example.com.", dns.rdatatype.A)
+            # For some reason Google's DNS over HTTPS fails when you POST to
+            # https://8.8.8.8/dns-query
+            # So we're just going to do GET requests here
+            r = dns.query.https(
+                q,
+                nameserver_ip,
+                post=False,
+                timeout=4,
+                http_version=dns.query.HTTPVersion.H3,
+            )
+            self.assertTrue(q.is_response(r))
+        if resolver_v6_addresses:
+            nameserver_ip = random.choice(resolver_v6_addresses)
+            q = dns.message.make_query("example.com.", dns.rdatatype.A)
+            r = dns.query.https(
+                q,
+                nameserver_ip,
+                post=False,
+                timeout=4,
+                http_version=dns.query.HTTPVersion.H3,
+            )
+            self.assertTrue(q.is_response(r))
+
+
 if __name__ == "__main__":
     unittest.main()
